## asasd

There are two tiers of Databricks workspaces:
- Standard. Requires a public IP.
- Premium. Allows for both public and private network implementations. In this project, premium workspaces will always generate private networking resources, such as private endpoints and private links. Regardless, users can still decide if they want to enable private frontends or not.
